package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.DeptVitalDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.facade.DeptVitalFacade;
import com.diagbot.vo.DeptVitalVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
 * 科室查体对应表 前端控制器
 * </p>
 *
 * @author zhaops
 * @since 2018-11-22
 */
@RestController
@RequestMapping("/deptVital")
@SuppressWarnings("unchecked")
@Api(value = "查体模板相关API", tags = { "查体模板相关API" })
public class DeptVitalController {

    @Autowired
    private DeptVitalFacade deptVitalFacade;

    @ApiOperation(value = "保存查体模板[by:zhaops]",
            notes = "deptId:科室ID，必填<br>" +
                    "vitalIds:查体标签ids，必填<br>")
    @PostMapping("/saveDeptVitals")
    @SysLogger("saveDeptVitals")
    public RespDTO<Boolean> saveDeptVitals(@RequestBody DeptVitalVO deptVitalVO) {
        Boolean data = deptVitalFacade.saveDeptVitals(deptVitalVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "删除模板标签-部分删除[by:zhaops]",
            notes = "deptId:科室ID，必填<br>" +
                    "vitalIds:查体标签ids，必填<br>")
    @PostMapping("/delDeptVitalList")
    @SysLogger("delDeptVitalList")
    public RespDTO<Boolean> delDeptVitalList(@RequestBody DeptVitalVO deptVitalVO) {
        Boolean data = deptVitalFacade.delDeptVitalList(deptVitalVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "删除模板标签-全删除[by:zhaops]",
            notes = "deptId:科室ID，必填<br>")
    @PostMapping("/delAllDeptVitalList")
    @SysLogger("delAllDeptVitalList")
    public RespDTO<Boolean> delAllDeptVitalList(@RequestParam("deptId") Long deptId) {
        Boolean data = deptVitalFacade.delAllDeptVitalList(deptId);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "根据科室ID获取查体模板[by:zhaops]",
            notes = "deptId:科室ID，必填<br>")
    @PostMapping("/getVitalsByDeptId")
    @SysLogger("getVitalsByDeptId")
    public RespDTO<List<QuestionInfo>> getVitalsByDeptId(@RequestParam("deptId") Long deptId) {
        List<QuestionInfo> data = deptVitalFacade.getVitalsByDeptId(deptId);
        return RespDTO.onSuc(data);
    }
}
